==========
Change log
==========

9.4 (2020-04-21)
================

- Update most libraries needed for the address book to their newest versions.

- Port code to Python 3.8, supporting now additionally to Python 2.7.


9.3 (2020-03-23)
================

- Update most libraries needed for the address book to their newest versions.

- Adapt `print.css` to menu changes in version 9.2.

- Prevent entering date values before 1900 as they cannot be rendered, so they
  even cannot be changed.

- Move source code to: https://github.com/icemac/icemac.addressbook.


9.2 (2019-12-30)
================

- Update most libraries needed for the address book to their newest versions.

- Fix padding on log-in form.

- On mobile devices replace horizontal menus (tabs) and the add menu with
  vertical ones hidden behind a burger icon resp. plus sign.

- Make header of application in browser less tall and move link to the about
  view to the main menu.


Previous Versions
=================

See `OLD_CHANGES.rst`_.

.. _`OLD_CHANGES.rst` : https://github.com/icemac/icemac.addressbook/blob/master/OLD_CHANGES.rst
.. _`documentation` :  https://icemacaddressbook.readthedocs.io/en/latest/runtheapplication.html
.. _`Upgrade installation` : https://icemacaddressbook.readthedocs.io/en/latest/upgrade-installation-manual-to-guided.html
.. _`archive documentation` :  https://icemacaddressbook.readthedocs.io/en/latest/operations.html
